@@ -1,5 +1,6 @@
 #include "lmaster.h"
 #include "ui_lmaster.h"
+extern void set_setting(QString,QString);
 
 lmaster::lmaster(QWidget *parent) :
     QDialog(parent),
@@ -24,13 +25,8 @@ case 2:currentQuery+="ORDER by `year` asc";break;
 case 3:currentQuery+="ORDER by `year` desc";break;
 }
 
-    QFile file("/home/user/.tplayer-list");
-         if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
-             return;
+set_setting("query",currentQuery);
 
-        QTextStream out(&file);
-        out<<currentQuery;
-        file.close();
 this->accept();
 this->close();
 }
