@@ -2,7 +2,7 @@
 #define OPTIONS_H
 #include <QtCore>
 #include <QtGui>
-
+#include <QtSql>
 #include "ui_dialog.h"
 
 
@@ -13,11 +13,9 @@ class options : public QDialog
 public:
     options(QWidget *parent = 0);
     Ui::Dialog ui;
-    QString base_path;
 signals:
 
 public slots:
-    void load(int,QString,int);
     void save();
 };
 
